import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.util.Random;

import javax.swing.JFrame;
import javax.swing.JMenu;
import javax.swing.JMenuBar;
import javax.swing.JMenuItem;
import javax.swing.SwingUtilities;

import com.mindfusion.common.DateTime;
import com.mindfusion.drawing.Colors;
import com.mindfusion.drawing.SolidBrush;
import com.mindfusion.spreadsheet.SortDirection;
import com.mindfusion.spreadsheet.SortKey;
import com.mindfusion.spreadsheet.SortOptions;
import com.mindfusion.spreadsheet.Workbook;
import com.mindfusion.spreadsheet.Worksheet;
import com.mindfusion.spreadsheet.WorksheetView;


public class Sorting
{
	public static void main(String[] args)
	{
		SwingUtilities.invokeLater(new Runnable()
		{
			public void run()
			{
				MainWindow window = new MainWindow();
				window.setTitle("JSpreadsheet Sample: Sorting");
				window.setVisible(true);
			}
		});
	}
	
	public static class MainWindow extends JFrame
	{
		public MainWindow()
		{
			setDefaultCloseOperation(EXIT_ON_CLOSE);
			setSize(1280, 1024);

			Workbook workbook = new Workbook();
			Worksheet worksheet = workbook.getWorksheets().add("Sorting");

			view = new WorksheetView();
			view.setWorksheet(worksheet);
			add(view);

			JMenuBar menuBar = new JMenuBar();
			JMenu menu = new JMenu("Data");
			menuBar.add(menu);

			JMenuItem menuItem = new JMenuItem("Generate");
			menuItem.addActionListener(new ActionListener()
			{
				@Override
				public void actionPerformed(ActionEvent e)
				{
					// Generate random data
					Random random = new Random(DateTime.now().getMillisecond());
					Worksheet activeSheet = view.getWorksheet();

					activeSheet.beginInit();
					for (int c = 1; c <= 20; c++)
					{
						for (int r = 1; r <= 50; r++)
							activeSheet.getCells().get(c, r).setData(random.nextInt(1000));
					}
					for (int c = 1; c <= 20; c++)
						activeSheet.getCells().get(c, 0).setData(String.format("Heading %1$d", c));
					for (int r = 1; r <= 50; r++)
						activeSheet.getCells().get(0, r).setData(String.format("Entry %1$d", r));
					activeSheet.getCellRanges().get(1, 0, 20, 0).getStyle().setBackground(new SolidBrush(Colors.LightSteelBlue));
					activeSheet.getCellRanges().get(0, 1, 0, 50).getStyle().setBackground(new SolidBrush(Colors.LightSteelBlue));
					activeSheet.endInit();

					// Select the generated data
					view.getSelection().set(1, 1, 20, 50);
				}
			});
			menu.add(menuItem);

			menu = new JMenu("Sort");
			menuBar.add(menu);

			menuItem = new JMenuItem("Horizontally");
			menuItem.addActionListener(new ActionListener()
			{
				@Override
				public void actionPerformed(ActionEvent e)
				{
					Worksheet activeSheet = view.getWorksheet();
					if (activeSheet == null)
						activeSheet = workbook.getWorksheets().add();
					SortOptions sortOptions = new SortOptions();
					sortOptions.setDirection(SortDirection.LeftToRight);
					sortOptions.getKeys().add(new SortKey(view.getActiveCell().getRow()));
					activeSheet.sort(view.getSelection().getRange(), sortOptions);
				}
			});
			menu.add(menuItem);
			menuItem = new JMenuItem("Vertically");
			menuItem.addActionListener(new ActionListener()
			{
				@Override
				public void actionPerformed(ActionEvent e)
				{
					Worksheet activeSheet = view.getWorksheet();
					if (activeSheet == null)
						activeSheet = workbook.getWorksheets().add();
					SortOptions sortOptions = new SortOptions();
					sortOptions.setDirection(SortDirection.TopToBottom);
					sortOptions.getKeys().add(new SortKey(view.getActiveCell().getColumn()));
					activeSheet.sort(view.getSelection().getRange(), sortOptions);
				}
			});
			menu.add(menuItem);

			setJMenuBar(menuBar);
		}


		private static final long serialVersionUID = 1L;

		private WorksheetView view;
	}
}